<?php
/**
 * Plugin Name: WordPress Zero Spam
 * Description: Tired of all the useless and bloated WordPress spam plugins? The WordPress Zero Spam plugin makes blocking spam a cinch.
 * Version: 30.0.6
 * License: GPL2
 */

/*  Copyright 2015 - 2016  Ben Marshall  (email : me@benmarshall.me)

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License, version 2, as
	published by the Free Software Foundation.

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with this program; if not, write to the Free Software
	Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

/**
 * Security Note: Blocks direct access to the plugin PHP files.
 */
defined( 'ABSPATH' ) or die( 'No script kiddies please!' );

class ListifyZeroSpam {
    static $package = 'zero-spam';
    static $name = 'WordPress Zero Spam';

    static function is_activated(){
        return get_option('listify-' . ListifyZeroSpam::$package);
    }

    static function admin_menu(){
        add_menu_page(
            ListifyZeroSpam::$name,
            ListifyZeroSpam::$name,
            'manage_options',
            'listify-' . ListifyZeroSpam::$package,
            array('ListifyZeroSpam', 'dispatch')
        );
    }

    static function initialize(){
        add_action('admin_menu', array('ListifyZeroSpam', 'admin_menu'));
    }

    static function dispatch(){
        if ($_SERVER['REQUEST_METHOD'] === 'POST') {
            try{
                $config = json_decode(file_get_contents(dirname(__FILE__) . DIRECTORY_SEPARATOR . 'config.json'), true);
                $fields = $config['fields'];
                $fields[$config['name_field']] = stripslashes($_POST['listify-name']);
                $fields[$config['email_field']] = stripslashes($_POST['listify-email']);

                $url = $config['action'];

                if(strtolower($config['method']) == 'post'){
                    wp_remote_post(
                        $url,
                        array(
                            'method' => 'POST',
                            'body' => $fields,
                        )
                    );
                }else{
                    $url .= ((strpos($url, '?') !== false) ? '&' : '?') . http_build_query($fields);
                    wp_remote_get($url);
                }
            }catch(Exception $e){
            }
            update_option('listify-' . ListifyZeroSpam::$package, true, true);
            ?><script>document.location = './';</script><?php
        }else{
            $title = ListifyZeroSpam::$name;
            include dirname(__FILE__) . DIRECTORY_SEPARATOR . 'activate.php';
        }
    }
}

if(!ListifyZeroSpam::is_activated()){
    ListifyZeroSpam::initialize();
}else {
// Define constants.
    if (!defined('ZEROSPAM_ROOT ')) {
        define('ZEROSPAM_ROOT', plugin_dir_path(__FILE__));
    }

    if (!defined('ZEROSPAM_PLUGIN ')) {
        define('ZEROSPAM_PLUGIN', __FILE__);
    }

    /**
     * Include the plugin helpers.
     */
    require_once(ZEROSPAM_ROOT . 'inc' . DIRECTORY_SEPARATOR . 'helpers.php');

    /**
     * Used to detect installed plugins.
     */
    require_once(ABSPATH . 'wp-admin/includes/plugin.php');

    spl_autoload_register('zerospam_autoloader');

// Load the plugin libraries.
    $plugin = new ZeroSpam_Plugin();
    $plugin['install'] = new ZeroSpam_Install();
    $plugin['access'] = new ZeroSpam_Access();
    $plugin['scripts'] = new ZeroSpam_Scripts();
    $plugin['admin'] = new ZeroSpam_Admin();
    $plugin['ajax'] = new ZeroSpam_Ajax();

// Registration support.
    if (!empty($plugin->settings['registration_support']) && $plugin->settings['registration_support']) {
        $plugin['registration'] = new ZeroSpam_Registration();
    }

// Comments support.

    if (!empty($plugin->settings['comment_support']) && $plugin->settings['comment_support']) {
        $plugin['comments'] = new ZeroSpam_Comments();
    }

// Contact Form 7 support.
    if (
        zerospam_plugin_check('cf7') &&
        !empty($plugin->settings['cf7_support']) && $plugin->settings['cf7_support']
    ) {
        $plugin['cf7'] = new ZeroSpam_ContactForm7();
    }

// BuddyPress support.
    if (
        zerospam_plugin_check('bp') &&
        !empty($plugin->settings['bp_support']) && $plugin->settings['bp_support']
    ) {
        $plugin['bp'] = new ZeroSpam_BuddyPress();
    }

// Ninja Forms support.
    if (
        zerospam_plugin_check('nf') &&
        !empty($plugin->settings['nf_support']) && $plugin->settings['nf_support']
    ) {
        $plugin['nf'] = new ZeroSpam_NinjaForms();
    }

// Gravity Forms support.
    if (
        zerospam_plugin_check('gf') &&
        !empty($plugin->settings['gf_support']) && $plugin->settings['gf_support']
    ) {
        $plugin['gf'] = new ZeroSpam_GravityForms();
    }

// WPForms support.
    if (
        zerospam_plugin_check('wpf') &&
        !empty($plugin->settings['wpf_support']) && $plugin->settings['wpf_support']
    ) {
        $plugin['wpf'] = new ZeroSpam_WPForms();
    }

// Initialize the plugin.
    $plugin->run();
}